@@ -1,6 +1,6 @@
 import os
 
-def frp_connect(server_host,server_port,token,password):
+def client(server_host,server_port,token,password):
     #ssh
     os.system("apt-get -qq update && apt-get -qq install -o=Dpkg::Use-Pty=0 openssh-server pwgen > /dev/null")
     print(server_host)
@@ -18,6 +18,7 @@ def frp_connect(server_host,server_port,token,password):
     os.system("kill -9 $(ps aux | grep 'frpc' | awk '{print $2}')")
     os.system('wget https://github.com/fatedier/frp/releases/download/v0.35.1/frp_0.35.1_linux_amd64.tar.gz')
     os.system('tar -zxvf frp_0.35.1_linux_amd64.tar.gz')
+    os.system('cat frp_0.35.1_linux_amd64/frpc.ini')
     with open('frp_0.35.1_linux_amd64/frpc.ini', 'w') as f:
         f.write('''
 [common]
@@ -31,4 +32,4 @@ local_ip = 127.0.0.1
 local_port = 22
 remote_port = 6000
         '''.strip()%(server_host,server_port,token))
-    os.system('./frp_0.35.1_linux_amd64/frpc -c ./frp_0.35.1_linux_amd64/frpc.ini')
\ No newline at end of file
+    os.system('nohup ./frp_0.35.1_linux_amd64/frpc -c ./frp_0.35.1_linux_amd64/frpc.ini &')
\ No newline at end of file
